Learn R Programming

SynergizeR (version 0.2)

available_species: This method takes as parameter a single string, representing an authority, and returns a character vector corresponding to the currently available species for the chosen authority.

Description

This method takes as parameter a single string, representing an authority, and returns a character vector corresponding to the currently available species for the chosen authority.

Usage

available_species(authority = "ensembl")

Arguments

authority
A character containing any authoritative sources of identifier-mapping information.

Value

A vector containing the currently available species for the chosen authority.

References

http://llama.mshri.on.ca/synergizer/translate/

Examples

Run this code
## Not run: 
# library('SynergizerR')
# available_species('ensembl') ## End(Not run)

Run the code above in your browser using DataLab